@@ -1,5 +1,5 @@
 #replicated study (lme) for data entry
 RepMIXdata<-function(TotalData)
 {
-BANOVAdata(TotalData,replicated=TRUE)
+BANOVAdata(TotalData,replicated=TRUE, parallel=FALSE)
 }
\ No newline at end of file
