@@ -1,4 +1,4 @@
 RepNCAplot<-function(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis){
   NCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,
-                  replicated=TRUE)
+                  replicated=TRUE, parallel=FALSE)
   }
\ No newline at end of file
