@@ -1,7 +1,7 @@
 ###Aceto revised NCA codes for lambda_z (WinNolin)
 options(warn=-1)
-TTTAIC<-function(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1,
-              separateWindows=TRUE,Demo=FALSE, BANOVA=FALSE,replicated=FALSE,MIX=FALSE, parallel=FALSE)
+TTTAIC<-function(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1, Tau, TlastD,SingleRdata0,SingleTdata0,  
+              separateWindows=TRUE,Demo=FALSE, BANOVA=FALSE,replicated=FALSE,MIX=FALSE, parallel=FALSE, multiple=FALSE)
 {
 description_TTTAIC()
 #split dataframe into sub-dataframe by subject for reference data
@@ -33,6 +33,7 @@ description_TTTAIC()
      #cat("<<Output: linear regression model: conc. vs. time>>\n")
      #calculate AUC
       CmaxRef<-0
+      CminRef<-0
       AUCINFRef<-0
       AUCTRef<-0
       TmaxRef<-0
@@ -41,6 +42,8 @@ description_TTTAIC()
       VdFRef<-0
       KelRef<-0
       ClFRef<-0
+      CavRef<-0
+      FluRef<-0
       ke<-0
       R_sq<-0
       AR_sq<-0
@@ -65,38 +68,61 @@ description_TTTAIC()
              auc_ref <-0
              tmax_ref<-0
              Cmax_ref<-0
+             Cmin_ref<-0
              aumc_ref<-0
             for(i in 2:length(R.split[[j]][["time"]])){
              #calculate AUC and exclude AUC==NA (auc<-0)
              auc_ref[i]<-(R.split[[j]][["time"]][i]-R.split[[j]][["time"]][i-1])*(R.split[[j]][["conc"]][i]+R.split[[j]][["conc"]][i-1])* 0.5
              auc_ref[i]<-auc_ref[i]+auc_ref[i-1]
              #calculate AUMC
-             aumc_ref[i]<-((R.split[[j]][["time"]][i])*(R.split[[j]][["conc"]][i])+(R.split[[j]][["time"]][i-1])*(R.split[[j]][["conc"]][i-1]))*
+             if(multiple){
+                aumc_ref[i]<-((R.split[[j]][["time"]][i]-TlastD)*(R.split[[j]][["conc"]][i])+(R.split[[j]][["time"]][i-1]-TlastD)*(R.split[[j]][["conc"]][i-1]))*
+                          ((R.split[[j]][["time"]][i]-TlastD)-(R.split[[j]][["time"]][i-1]-TlastD))* 0.5
+               }
+             else{
+                aumc_ref[i]<-((R.split[[j]][["time"]][i])*(R.split[[j]][["conc"]][i])+(R.split[[j]][["time"]][i-1])*(R.split[[j]][["conc"]][i-1]))*
                           ((R.split[[j]][["time"]][i])-(R.split[[j]][["time"]][i-1]))* 0.5
+               }
              aumc_ref[i]<-aumc_ref[i]+aumc_ref[i-1]
              Cmax_ref<-max(R.split[[j]][["conc"]], na.rm = FALSE)
-              }
+             Cmin_ref<-min(R.split[[j]][["conc"]], na.rm = FALSE)
+             }
 
               #calculate AUC (0~INF)
                auc.infinity<-R.split[[j]][["conc"]][length(R.split[[j]][["conc"]])]/ke[j]
                aucINF<-auc_ref[length(R.split[[j]][["conc"]])]+auc.infinity
 
                 #calculate AUMC (0~INF)
+                  if(multiple){
+                  aumc.infinity_1<-(R.split[[j]][["conc"]][length(R.split[[j]][["conc"]])])*(R.split[[j]][["time"]][length(R.split[[j]][["time"]])]-TlastD)/ke[j]
+                   }
+                  else{
                   aumc.infinity_1<-(R.split[[j]][["conc"]][length(R.split[[j]][["conc"]])])*(R.split[[j]][["time"]][length(R.split[[j]][["time"]])])/ke[j]
+                  }
                   aumc.infinity_2<-(R.split[[j]][["conc"]][length(R.split[[j]][["conc"]])]/(ke[j]^2))
                   aumcINF<-aumc_ref[length(R.split[[j]][["conc"]])]+aumc.infinity_1+aumc.infinity_2
 
                    #for summary result
                   CmaxRef[j]<-Cmax_ref
+                  CminRef[j]<-Cmin_ref
                   AUCINFRef[j]<-aucINF
                   AUCTRef[j]<-auc_ref[length(R.split[[j]][["conc"]])]
                   TmaxRef[j]<-R.split[[j]]$time[xr] #R.split[[j]][xr,5]->R.split[[j]]$time[xr]
-                  MRTINFRef[j]<-aumcINF/aucINF
                   T12Ref[j]<-log(2)/ke[j]
-                  VdFRef[j]<-Dose/(aucINF*ke[j])
                   KelRef[j]<-ke[j]
-                  ClFRef[j]<-Dose/aucINF
-
+                  
+                   if(multiple){
+                       VdFRef[j]<-Dose/((auc_ref[length(R.split[[j]][["conc"]])])*ke[j])
+                       ClFRef[j]<-Dose/(auc_ref[length(R.split[[j]][["conc"]])])
+                       MRTINFRef[j]<-(aumc_ref[length(R.split[[j]][["conc"]])])/(auc_ref[length(R.split[[j]][["conc"]])])
+                       CavRef[j]<-(auc_ref[length(R.split[[j]][["conc"]])])/Tau
+                       FluRef[j]<-((Cmax_ref-Cmin_ref)/((auc_ref[length(R.split[[j]][["conc"]])])/Tau))*100
+                      }
+                      else{
+                       VdFRef[j]<-Dose/(aucINF*ke[j])
+                       ClFRef[j]<-Dose/aucINF
+                       MRTINFRef[j]<-aumcINF/aucINF 
+                      }
                  cat("\n")
                  if(replicated){
                  cat("<< NCA Outputs:- Subj.#",R.split[[j]][["subj"]][1],", Seq",R.split[[j]][["seq"]][1],", Prd",R.split[[j]][["prd"]][1]," (Ref.)>>\n")
@@ -106,7 +132,12 @@ description_TTTAIC()
                     }
                  cat("--------------------------------------------------------------------------\n")
                  output<-data.frame(R.split[[j]][["subj"]],R.split[[j]][["time"]],R.split[[j]][["conc"]],formatC(auc_ref,format="f",digits=3),formatC(aumc_ref,format="f",digits=3))
-                 colnames(output)<-list("subj","time","conc", "AUC(0-t)","AUMC(0-t)")
+                 if(multiple){
+                  colnames(output)<-list("subj","time","conc", "AUC(tau)ss","AUMC(tau)ss")
+                  }
+                  else{
+                  colnames(output)<-list("subj","time","conc", "AUC(0-t)","AUMC(0-t)")
+                  }
                  show(output)
 
                  cat("--------------------------------------------------------------------------\n")
@@ -120,6 +151,25 @@ description_TTTAIC()
 
               cat("\n<<Final PK Parameters>>\n")
               cat("----------------------------\n")
+               if(multiple){
+              cat("           R sq. =",R_sq[j] ,"\n")
+              cat("Adj. R sq. (ARS) =",AR_sq[j] ,"\n")
+              cat("        lambda_z =",ke[j] ,"\n")
+              cat("         Cmax_ss =",Cmax_ref ,"\n")
+              cat("         Cmin_ss =",Cmin_ref ,"\n")
+              cat("         Tmax_ss =",TmaxRef[j] ,"\n")
+              cat("             Cav =",(auc_ref[length(R.split[[j]][["conc"]])])/Tau ,"\n")
+              cat("  Fluctuation(%) =",((Cmax_ref-Cmin_ref)/((auc_ref[length(R.split[[j]][["conc"]])])/Tau))*100 ,"\n")
+              cat("            Cl/F =",Dose/(auc_ref[length(R.split[[j]][["conc"]])]),"\n")
+              cat("            Vd/F =",Dose/((auc_ref[length(R.split[[j]][["conc"]])])*ke[j]),"\n")
+              cat("         T1/2(z) =",log(2)/ke[j],"\n")
+              cat("      AUC(tau)ss =",auc_ref[length(R.split[[j]][["conc"]])],"\n")
+              cat("     AUMC(tau)ss =",aumc_ref[length(R.split[[j]][["conc"]])],"\n")
+              cat("             MRT =",(aumc_ref[length(R.split[[j]][["conc"]])])/(auc_ref[length(R.split[[j]][["conc"]])]),"\n")
+              cat("--------------------------------------------------------------------------\n")
+              cat("\n\n")
+                }
+              else{
               cat("           R sq. =",R_sq[j] ,"\n")
               cat("Adj. R sq. (ARS) =",AR_sq[j] ,"\n")
               cat("             AIC =",aic[j] ,"\n")
@@ -137,6 +187,7 @@ description_TTTAIC()
               cat("      MRT(0-inf) =",aumcINF/aucINF,"\n")
               cat("--------------------------------------------------------------------------\n")
               cat("\n\n")
+                }
               }
 ke_melt<-melt(ke)
 R_melt<-melt(R_sq)
@@ -170,6 +221,7 @@ if(replicated){
 #cat("<<Output: linear regression model: conc. vs. time>>\n")
   #calculate AUC
     CmaxTest<-0
+    CminTest<-0
     AUCINFTest<-0
     AUCTTest<-0
     TmaxTest<-0
@@ -178,6 +230,8 @@ if(replicated){
     VdFTest<-0
     KelTest<-0
     ClFTest<-0
+    CavTest<-0
+    FluTest<-0
     ke1<-0
     R_sq1<-0
     AR_sq1<-0
@@ -201,6 +255,7 @@ if(replicated){
 
           auc_test <-0
           Cmax_test<-0
+          Cmin_test<-0
           tmax_test<-0
           aumc_test<-0
 
@@ -209,10 +264,17 @@ if(replicated){
              auc_test[i]<-(T.split[[j]][["time"]][i]-T.split[[j]][["time"]][i-1])*(T.split[[j]][["conc"]][i]+T.split[[j]][["conc"]][i-1])* 0.5
              auc_test[i]<-auc_test[i]+auc_test[i-1]
              #calculate AUMC
+              if(multiple){
+             aumc_test[i]<-((T.split[[j]][["time"]][i]-TlastD)*(T.split[[j]][["conc"]][i])+(T.split[[j]][["time"]][i-1]-TlastD)*(T.split[[j]][["conc"]][i-1]))*
+                          ((T.split[[j]][["time"]][i]-TlastD)-(T.split[[j]][["time"]][i-1]-TlastD))* 0.5
+               }
+             else{
              aumc_test[i]<-((T.split[[j]][["time"]][i])*(T.split[[j]][["conc"]][i])+(T.split[[j]][["time"]][i-1])*(T.split[[j]][["conc"]][i-1]))*
                           ((T.split[[j]][["time"]][i])-(T.split[[j]][["time"]][i-1]))* 0.5
+              } 
              aumc_test[i]<-aumc_test[i]+aumc_test[i-1]
              Cmax_test<-max(T.split[[j]][["conc"]], na.rm = FALSE)
+             Cmin_test<-min(T.split[[j]][["conc"]], na.rm = FALSE)
               }
 
               #calculate AUC (0~INF)
@@ -220,20 +282,36 @@ if(replicated){
                aucINF<-auc_test[length(T.split[[j]][["conc"]])]+auc.infinity
 
                 #calculate AUMC (0~INF)
-                  aumc.infinity_1<-(T.split[[j]][["conc"]][length(T.split[[j]][["conc"]])])*(T.split[[j]][["time"]][length(T.split[[j]][["time"]])])/ke1[j]
+                   if(multiple){
+                   aumc.infinity_1<-(T.split[[j]][["conc"]][length(T.split[[j]][["conc"]])])*(T.split[[j]][["time"]][length(T.split[[j]][["time"]])]-TlastD)/ke1[j]
+                   }
+                   else{
+                   aumc.infinity_1<-(T.split[[j]][["conc"]][length(T.split[[j]][["conc"]])])*(T.split[[j]][["time"]][length(T.split[[j]][["time"]])])/ke1[j]
+                   }
                   aumc.infinity_2<-(T.split[[j]][["conc"]][length(T.split[[j]][["conc"]])]/(ke1[j]^2))
                   aumcINF<-aumc_test[length(T.split[[j]][["conc"]])]+aumc.infinity_1+aumc.infinity_2
 
                   #for summary result
                   CmaxTest[j]<-Cmax_test
+                  CminTest[j]<-Cmin_test
                   AUCINFTest[j]<-aucINF
                   AUCTTest[j]<-auc_test[length(T.split[[j]][["conc"]])]
                   TmaxTest[j]<-T.split[[j]]$time[xt] #T.split[[j]][xt,5] -->T.split[[j]]$time[xt]
-                  MRTINFTest[j]<-aumcINF/aucINF
                   T12Test[j]<-log(2)/ke1[j]
-                  VdFTest[j]<-Dose/(aucINF*ke1[j])
                   KelTest[j]<-ke1[j]
+                 
+                      if(multiple){
+                  VdFTest[j]<-Dose/((auc_test[length(T.split[[j]][["conc"]])])*ke1[j])
+                  ClFTest[j]<-Dose/(auc_test[length(T.split[[j]][["conc"]])])
+                  MRTINFTest[j]<-(aumc_test[length(T.split[[j]][["conc"]])])/(auc_test[length(T.split[[j]][["conc"]])])
+                  CavTest[j]<-(auc_test[length(T.split[[j]][["conc"]])])/Tau
+                  FluTest[j]<-((Cmax_test-Cmin_test)/((auc_test[length(T.split[[j]][["conc"]])])/Tau))*100
+                    }
+                    else{
+                  VdFTest[j]<-Dose/(aucINF*ke1[j])
                   ClFTest[j]<-Dose/aucINF
+                  MRTINFTest[j]<-aumcINF/aucINF     
+                        }
 
                  cat("\n")
                  if(replicated){
@@ -244,7 +322,12 @@ if(replicated){
                     }
                  cat("--------------------------------------------------------------------------\n")
                  output<-data.frame(T.split[[j]][["subj"]],T.split[[j]][["time"]],T.split[[j]][["conc"]],formatC(auc_test,format="f",digits=3),formatC(aumc_test,format="f",digits=3) )
-                 colnames(output)<-list("subj","time","conc", "AUC(0-t)","AUMC(0-t)")
+                   if(multiple){
+                  colnames(output)<-list("subj","time","conc", "AUC(tau)ss","AUMC(tau)ss")
+                  }
+                  else{
+                  colnames(output)<-list("subj","time","conc", "AUC(0-t)","AUMC(0-t)")
+                  }
                  show(output)
 
                  cat("--------------------------------------------------------------------------\n")
@@ -258,6 +341,25 @@ if(replicated){
 
               cat("\n<<Final PK Parameters>>\n")
               cat("----------------------------\n")
+              if(multiple){
+              cat("           R sq. =",R_sq1[j] ,"\n")
+              cat("Adj. R sq. (ARS) =",AR_sq1[j] ,"\n")
+              cat("        lambda_z =",ke1[j] ,"\n")
+              cat("         Cmax_ss =",Cmax_test ,"\n")
+              cat("         Cmin_ss =",Cmin_test ,"\n")
+              cat("         Tmax_ss =",TmaxTest[j] ,"\n")
+              cat("             Cav =",(auc_test[length(T.split[[j]][["conc"]])])/Tau ,"\n")
+              cat("  Fluctuation(%) =",((Cmax_test-Cmin_test)/((auc_test[length(T.split[[j]][["conc"]])])/Tau))*100 ,"\n")
+              cat("            Cl/F =",Dose/(auc_test[length(T.split[[j]][["conc"]])]),"\n")
+              cat("            Vd/F =",Dose/((auc_test[length(T.split[[j]][["conc"]])])*ke1[j]),"\n")
+              cat("         T1/2(z) =",log(2)/ke1[j],"\n")
+              cat("      AUC(tau)ss =",auc_test[length(T.split[[j]][["conc"]])],"\n")
+              cat("     AUMC(tau)ss =",aumc_test[length(T.split[[j]][["conc"]])],"\n")
+              cat("             MRT =",(aumc_test[length(T.split[[j]][["conc"]])])/(auc_test[length(T.split[[j]][["conc"]])]),"\n")
+              cat("--------------------------------------------------------------------------\n")
+              cat("\n\n") 
+              }
+              else{  
               cat("           R sq. =",R_sq1[j] ,"\n")
               cat("Adj. R sq. (ARS) =",AR_sq1[j] ,"\n")
               cat("             AIC =",aic1[j] ,"\n")
@@ -275,6 +377,7 @@ if(replicated){
               cat("      MRT(0-inf) =",aumcINF/aucINF,"\n")
               cat("--------------------------------------------------------------------------\n")
               cat("\n\n")
+              }
  }
 ke1_melt<-melt(ke1)
 R1_melt<-melt(R_sq1)
@@ -310,11 +413,20 @@ subjT<-0
      subjT[j]<-T.split[[j]][["subj"]][1]
      }
 if(parallel){
-description_Repdrugcode()
-sumindexR<-data.frame(subj=subjR,drug=c(1),Cmax=CmaxRef,AUC0t=AUCTRef,AUC0INF=AUCINFRef,
+ if(multiple){
+  description_Multipledrugcode() 
+  sumindexR<-data.frame(subj=subjR,drug=c(1),Cmax=CmaxRef,AUC0t=AUCTRef,Cmin=CminRef,
+                       Tmax=TmaxRef, MRTINF=MRTINFRef, T12=T12Ref, VdF=VdFRef, Kel=KelRef, ClF=ClFRef, Cav=CavRef, Flu=FluRef)
+  sumindexT<-data.frame(subj=subjT,drug=c(2),Cmax=CmaxTest,AUC0t=AUCTTest,Cmin=CminTest,
+                       Tmax=TmaxTest,MRTINF=MRTINFTest, T12=T12Test, VdF=VdFTest, Kel=KelTest, ClF=ClFTest, Cav=CavTest, Flu=FluTest)
+  }
+  else{
+  description_Repdrugcode()
+  sumindexR<-data.frame(subj=subjR,drug=c(1),Cmax=CmaxRef,AUC0t=AUCTRef,AUC0INF=AUCINFRef,
                       Tmax=TmaxRef, MRTINF=MRTINFRef, T12=T12Ref, VdF=VdFRef, Kel=KelRef, ClF=ClFRef)
-sumindexT<-data.frame(subj=subjT,drug=c(2),Cmax=CmaxTest,AUC0t=AUCTTest,AUC0INF=AUCINFTest,
+  sumindexT<-data.frame(subj=subjT,drug=c(2),Cmax=CmaxTest,AUC0t=AUCTTest,AUC0INF=AUCINFTest,
                      Tmax=TmaxTest,MRTINF=MRTINFTest, T12=T12Test, VdF=VdFTest, Kel=KelTest, ClF=ClFTest) 
+  }
 }
  else{
  seqR<-0
@@ -351,23 +463,44 @@ sumindexT<-data.frame(subj=subjT,drug=drugT,seq=seqT,prd=prdT,Cmax=CmaxTest,AUC0
                      Tmax=TmaxTest,MRTINF=MRTINFTest, T12=T12Test, VdF=VdFTest, Kel=KelTest, ClF=ClFTest) 
    }
 else{
-description_drugcode()
-sumindexR<-data.frame(subj=subj,drug=c(1),seq=seqR,prd=prdR,Cmax=CmaxRef,AUC0t=AUCTRef,AUC0INF=AUCINFRef,
+if(multiple){
+         description_Multipledrugcode()
+         sumindexR<-data.frame(subj=subjR,drug=c(1),seq=seqR,prd=prdR,Cmax=CmaxRef,AUC0t=AUCTRef,Cmin=CminRef,
+                      Tmax=TmaxRef, MRTINF=MRTINFRef, T12=T12Ref, VdF=VdFRef, Kel=KelRef, ClF=ClFRef, Cav=CavRef, Flu=FluRef)
+         sumindexT<-data.frame(subj=subjT,drug=c(2),seq=seqT,prd=prdT,Cmax=CmaxTest,AUC0t=AUCTTest,Cmin=CminTest,
+                     Tmax=TmaxTest,MRTINF=MRTINFTest, T12=T12Test, VdF=VdFTest, Kel=KelTest, ClF=ClFTest, Cav=CavTest, Flu=FluTest)
+         }
+        else{
+          description_drugcode()
+          sumindexR<-data.frame(subj=subjR,drug=c(1),seq=seqR,prd=prdR,Cmax=CmaxRef,AUC0t=AUCTRef,AUC0INF=AUCINFRef,
                       Tmax=TmaxRef, MRTINF=MRTINFRef, T12=T12Ref, VdF=VdFRef, Kel=KelRef, ClF=ClFRef)
-sumindexT<-data.frame(subj=subj,drug=c(2),seq=seqT,prd=prdT,Cmax=CmaxTest,AUC0t=AUCTTest,AUC0INF=AUCINFTest,
+          sumindexT<-data.frame(subj=subjT,drug=c(2),seq=seqT,prd=prdT,Cmax=CmaxTest,AUC0t=AUCTTest,AUC0INF=AUCINFTest,
                      Tmax=TmaxTest,MRTINF=MRTINFTest, T12=T12Test, VdF=VdFTest, Kel=KelTest, ClF=ClFTest)
+        }
   }
 }  
 #########
 Total<-rbind(sumindexR,sumindexT)
 if(parallel){
-TotalData<-data.frame (subj=as.factor(Total$subj), drug=as.factor(Total$drug),Cmax=Total$Cmax, AUC0t=Total$AUC0t, AUC0INF=Total$AUC0INF,
+  if(multiple){
+  TotalData<-data.frame (subj=as.factor(Total$subj), drug=as.factor(Total$drug),Cmax_ss=Total$Cmax, AUCtau_ss=Total$AUC0t,
+                         lnCmax_ss=log(Total$Cmax),lnAUCtau_ss=log(Total$AUC0t))
+  }
+  else{
+  TotalData<-data.frame (subj=as.factor(Total$subj), drug=as.factor(Total$drug),Cmax=Total$Cmax, AUC0t=Total$AUC0t, AUC0INF=Total$AUC0INF,
                       lnCmax=log(Total$Cmax),lnAUC0t=log(Total$AUC0t),lnAUC0INF=log(Total$AUC0INF))
+   }
 }
 else{
-TotalData<-data.frame (subj=as.factor(Total$subj), drug=as.factor(Total$drug),seq=as.factor(Total$seq),
+if(multiple){
+  TotalData<-data.frame (subj=as.factor(Total$subj), drug=as.factor(Total$drug),seq=as.factor(Total$seq),
+                   prd=as.factor(Total$prd),Cmax_ss=Total$Cmax, AUCtau_ss=Total$AUC0t,lnCmax_ss=log(Total$Cmax),lnAUCtau_ss=log(Total$AUC0t))
+  }
+  else{
+   TotalData<-data.frame (subj=as.factor(Total$subj), drug=as.factor(Total$drug),seq=as.factor(Total$seq),
                    prd=as.factor(Total$prd),Cmax=Total$Cmax, AUC0t=Total$AUC0t, AUC0INF=Total$AUC0INF,
                    lnCmax=log(Total$Cmax),lnAUC0t=log(Total$AUC0t),lnAUC0INF=log(Total$AUC0INF))
+   }
 }
 show(TotalData)
 
@@ -378,13 +511,22 @@ show(TotalData)
 Totalplot<-Totalplot[ do.call(order, Totalplot) ,]
 s.split<-split(Totalplot,list(Totalplot$subj))
 if(parallel){
- Totalplot$conc[Totalplot$conc == 0] <- NA
- Totalplot <- na.omit(Totalplot)
- Totalplot.split<-split(Totalplot, list(Totalplot$subj))
+ if(multiple){
+    paraR.split<-split(SingleRdata1, list(SingleRdata1$subj))
+    paraT.split<-split(SingleTdata1, list(SingleTdata1$subj))
+    
+    RR.split<-split(SingleRdata0, list(SingleRdata0$subj))
+    TT.split<-split(SingleTdata0, list(SingleTdata0$subj))
+   }
+   else{
+    Totalplot$conc[Totalplot$conc == 0] <- NA
+    Totalplot <- na.omit(Totalplot)
+    Totalplot.split<-split(Totalplot, list(Totalplot$subj))
  
- Totalplotpara<-split( Totalplot, list(Totalplot$drug))
- paraR.split<-split( Totalplotpara[[1]], list(Totalplotpara[[1]]$subj))
- paraT.split<-split( Totalplotpara[[2]], list(Totalplotpara[[2]]$subj))   
+    Totalplotpara<-split( Totalplot, list(Totalplot$drug))
+    paraR.split<-split( Totalplotpara[[1]], list(Totalplotpara[[1]]$subj))
+    paraT.split<-split( Totalplotpara[[2]], list(Totalplotpara[[2]]$subj))  
+     }
   }
  else{
  if(replicated){
@@ -397,6 +539,20 @@ if(parallel){
      Ls.split<-split(LR, list(LR$subj))
         }
   else{
+      if(multiple){
+     LR<-data.frame(subj=SingleRdata0$subj, time=SingleRdata0$time,  conc=SingleRdata0$conc)
+     LR$conc[LR$conc == 0] <- NA
+     LR <- na.omit(LR)
+     LR.split<-split(LR, list(LR$subj))
+     
+     LT<-data.frame(subj=SingleTdata0$subj, time=SingleTdata0$time,  conc=SingleTdata0$conc)
+     LT$conc[LT$conc == 0] <- NA
+     LT <- na.omit(LT)
+     LT.split<-split(LT, list(LT$subj))
+         RR.split<-split(SingleRdata0, list(SingleRdata0$subj))
+         TT.split<-split(SingleTdata0, list(SingleTdata0$subj))
+      }
+      else{
      LR<-data.frame(subj=SingleRdata$subj, time=SingleRdata$time,  conc=SingleRdata$conc)
      LR$conc[LR$conc == 0] <- NA
      LR <- na.omit(LR)
@@ -406,6 +562,7 @@ if(parallel){
      LT$conc[LT$conc == 0] <- NA
      LT <- na.omit(LT)
      LT.split<-split(LT, list(LT$subj))
+    }
    }
 }   
 windows(record = TRUE )
@@ -414,10 +571,20 @@ if(replicated){
    }
 else{ 
  if(parallel){
-    plotsingle.para(R.split, T.split, paraR.split,paraT.split,xaxis,yaxis )
+    if(multiple){
+       Multipleplotsingle.para(R.split,T.split,paraR.split,paraT.split,xaxis,yaxis,RR.split,TT.split,TlastD )
+       }
+      else{
+        plotsingle.para(R.split, T.split, paraR.split,paraT.split,xaxis,yaxis )
+      }
   }
   else{ 
-    plotsingle(LR.split,LT.split,R.split,T.split,xaxis,yaxis )
+   if(multiple){
+       Multipleplotsingle(LR.split,LT.split,RR.split,TT.split,xaxis,yaxis,TlastD )
+       }
+      else{
+        plotsingle(LR.split,LT.split,xaxis,yaxis,R.split,T.split )
+      }
   }
 }  
 ##export with txt file
@@ -441,6 +608,27 @@ RepNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis)
  }
 else{
    if(parallel){
+      if(multiple){
+        SingleRdata<-SingleRdata0
+        SingleTdata<-SingleTdata0
+        MultipleParaTTTAICoutput(sumindexR, sumindexT,R.split, T.split,keindex_ref,keindex_test,Dose,TotalData, Tau, TlastD)
+        MultipleParaNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,TlastD)
+          if (Demo){
+          #Demo=TRUE, BANOVA=FALSE
+          MultipleParamenu()
+          }
+           else {
+             if(MIX){
+            ##Demo=FALSE, BANOVA=TRUE
+             MultipleParaMIXanalyze(TotalData)
+                }
+             else{
+             #Demo=FALSE, BANOVA=FALSE
+             MultipleParaNCAsave(TotalData)
+               }
+             }
+        }
+      else{
       ParaTTTAICoutput(sumindexR, sumindexT,R.split, T.split,keindex_ref,keindex_test,Dose,TotalData )
       ParaNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis) 
       if (Demo){
@@ -458,11 +646,33 @@ else{
          ParaNCAsave(TotalData)
            }
          }     
-      }
+       }
+     } 
       else{
-       TTTAICoutput(sumindexR, sumindexT,R.split, T.split,keindex_ref,keindex_test,Dose,TotalData )
-       NCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis)
-
+        if(multiple){
+        SingleRdata<-SingleRdata0
+        SingleTdata<-SingleTdata0
+        MultipleTTTAICoutput(sumindexR, sumindexT,R.split, T.split,keindex_ref,keindex_test,Dose,TotalData, Tau, TlastD)
+        MultipleNCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis,TlastD)
+          if (Demo){
+          #Demo=TRUE, BANOVA=FALSE
+          MultipleNCAmenu()
+          }
+           else {
+             if(BANOVA){
+            ##Demo=FALSE, BANOVA=TRUE
+             dev.off()
+             MultipleBANOVAanalyze(TotalData)
+                }
+             else{
+             #Demo=FALSE, BANOVA=FALSE
+             MultipleNCAsave(TotalData)
+               }
+             }
+          }
+         else{
+        TTTAICoutput(sumindexR, sumindexT,R.split, T.split,keindex_ref,keindex_test,Dose,TotalData )
+        NCAplot(Totalplot,SingleRdata,SingleTdata,TotalData,xaxis,yaxis)
       if (Demo){
       #Demo=TRUE, BANOVA=FALSE
       NCAmenu()
@@ -476,6 +686,7 @@ else{
          else{
          #Demo=FALSE, BANOVA=FALSE
         NCAsave(TotalData)
+         }
        }
      }
    }
