@@ -5,7 +5,7 @@ description_plot<-function()
 par(mar=c(0,0,0,0)) 
 plot(0, xlim=c(0, 210), ylim=c(0, 297), col="white")
 text(100, 250,
-"~~~  This report is generated using bear v2.3.1 for R. ~~~",cex = .8)
+"~~~  This report is generated using bear v2.4.0 for R. ~~~",cex = .8)
 text(100, 240,
 "Authors: Hsin-ya Lee, Yung-jin Lee",cex = .8)
 text(100, 230,
@@ -18,6 +18,7 @@ text(100, 200,
 "bear's website: http://pkpd.kmu.edu.tw/bear",cex = .8)
 text(100, 190,
 "R website: http://www.r-project.org" ,cex = .8)
-
+text(100, 180,
+"Bebac Forum: R for BE/BA --> http://forum.bebac.at/?category=19" ,cex = .8)
 #par(mar=c(4,4,4,4)) # reset margins
 }
\ No newline at end of file
