@@ -6,39 +6,26 @@ if (noquote(unlist(format(.Platform)))[1] == "unix") {
         windows <<- function(record) {
         }
      }  
-
-      
+     
 cat("\n")
-  file.menu <- c("Sample size estimation for ABE ",
-                 "Noncompartmental analysis (NCA)",
-                 "Statistical analysis",
-                 "NCA --> Statistical analysis",
+  file.menu <- c("Single dose study ",
+                 "Multiple dose study",
                  "Quit")
    cat("\n")
   pick <- menu(file.menu, title = " << Top menu >> ")
     if (pick == 1){
       cat("\n")
-        sizemenu()}
+        Singlego()}
 
     else {
     if (pick == 2){
         cat("\n")
-        Multiplemenu()
+        Multiplego()
        }
     else {
     if (pick == 3){
-        cat("\n")
-        statmenu()
-         }
-   else {
-    if (pick == 4){
-        Multiplestatmenu()
-         }
-    else {
-    if (pick == 5){
         cat("\nThank you for using bear!  Bye now. \n\n")}
          }  
       }
-   }
- }
-}  
\ No newline at end of file
+}
+ 
\ No newline at end of file
